@@ -17,13 +17,14 @@ import pprint
 from enum import Enum
 from acryl.executor.report.execution_report import ExecutionReport
 from acryl.executor.context.execution_context import ExecutionContext
-from typing import List
+from typing import List, Optional
  
 class Type(Enum):
     SUCCESS = 1
     FAILURE = 2
     TIMEOUT = 3
     CANCELLED = 4
+    RUNNING = 5
 
 class ExecutionResult:
 
@@ -57,5 +58,9 @@ class ExecutionResult:
             summary += "Execution finished successfully!\n"
         return summary
 
+    def get_structured_report(self) -> Optional[str]:
+        return self.get_context().get_report().structured_report
+
+
     def pretty_print_summary(self):
         print(self.get_summary())
\ No newline at end of file
